@@ -4,11 +4,12 @@ use Moo;
 
 # ABSTRACT: Store::CouchDB - a simple CouchDB driver
 
-our $VERSION = '4.0'; # VERSION
+our $VERSION = '4.1'; # VERSION
 
 use MooX::Types::MooseLike::Base qw(:all);
 use experimental 'smartmatch';
 use JSON;
+use LWP::Protocol::Net::Curl;
 use LWP::UserAgent;
 use URI;
 use URI::QueryParam;
@@ -1042,7 +1043,7 @@ Store::CouchDB - Store::CouchDB - a simple CouchDB driver
 
 =head1 VERSION
 
-version 4.0
+version 4.1
 
 =head1 SYNOPSIS
 
@@ -1053,7 +1054,7 @@ library, it is just complete enough for the things I need to do.
 Refer to the CouchDB Documentation at: L<http://docs.couchdb.org/en/latest/>
 
     use Store::CouchDB;
-    
+
     my $sc = Store::CouchDB->new(host => 'localhost', db => 'your_db');
     # OR
     my $sc = Store::CouchDB->new();
@@ -1085,9 +1086,9 @@ Connect to host using SSL/TLS.
 
 Default: false
 
-=head2 db
+=head2 db / has_db
 
-The databae name to use.
+The database name to use.
 
 =head2 user
 
@@ -1103,7 +1104,7 @@ This is internal and sets the request method to be used (GET|POST)
 
 Default: GET
 
-=head2 error
+=head2 error / has_error
 
 This is set if an error has occured and can be called to get the last
 error with the 'has_error' predicate.
